@@ -1,6 +1,6 @@
 skip_if_no_cookie <- function() {
   testthat::skip_if_offline()
-  
+
   if (is.null(get_afl_cookie())) {
     skip("AFLW Cookie not working")
   }
@@ -50,7 +50,8 @@ test_that("fetch_results_afltables works for various inputs", {
   testthat::skip_on_cran()
 
   # TODO fix warnings
-
+  df <- fetch_results_afltables(1897:2021)
+  expect_false(anyNA(df$Home.Points))
   # test normal function
   expect_s3_class(fetch_results_afltables(2020, round = 1), "tbl")
 
@@ -107,7 +108,7 @@ test_that("old results functions returns deprecated warning", {
 test_that("get_match_results works", {
   testthat::skip_if_offline()
   testthat::skip_on_cran()
-  
+
   expect_warning(dat <- get_match_results())
   expect_type(dat, "list")
   expect_error(get_match_results("a"))
@@ -117,10 +118,8 @@ test_that("get_match_results works", {
 test_that("get_footywire_stats works", {
   testthat::skip_if_offline()
   testthat::skip_on_cran()
-  
+
   expect_warning(results <- get_footywire_match_results(2020, 2))
   expect_s3_class(results, "data.frame")
   expect_error(suppressWarnings(get_footywire_match_results("a")))
 })
-
-
